==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/GUITestBase/src/tests/common_scenarios/mca_editor/GTTestsMcaEditor.h <==
/**
* UGENE - Integrated Bioinformatics Tools.
* Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
* http://ugene.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
* MA 02110-1301, USA.
*/

#ifndef GTTESTSMCAEDITOR_H
#define GTTESTSMCAEDITOR_H

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_mca_editor {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_mca_editor"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012_1)
GUI_TEST_CLASS_DECLARATION(test_0012_2)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)
GUI_TEST_CLASS_DECLARATION(test_0013_3)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0015_2)
GUI_TEST_CLASS_DECLARATION(test_0016_1)
GUI_TEST_CLASS_DECLARATION(test_0016_2)
GUI_TEST_CLASS_DECLARATION(test_0017_1)
GUI_TEST_CLASS_DECLARATION(test_0017_2)
GUI_TEST_CLASS_DECLARATION(test_0018_1)
GUI_TEST_CLASS_DECLARATION(test_0018_2)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022_1)
GUI_TEST_CLASS_DECLARATION(test_0022_2)
GUI_TEST_CLASS_DECLARATION(test_0022_3)
GUI_TEST_CLASS_DECLARATION(test_0023_1)
GUI_TEST_CLASS_DECLARATION(test_0023_2)
GUI_TEST_CLASS_DECLARATION(test_0023_3)
GUI_TEST_CLASS_DECLARATION(test_0024_1)
GUI_TEST_CLASS_DECLARATION(test_0024_2)
GUI_TEST_CLASS_DECLARATION(test_0024_3)
GUI_TEST_CLASS_DECLARATION(test_0025_1)
GUI_TEST_CLASS_DECLARATION(test_0025_2)
GUI_TEST_CLASS_DECLARATION(test_0025_3)
GUI_TEST_CLASS_DECLARATION(test_0026_1)
GUI_TEST_CLASS_DECLARATION(test_0026_2)
GUI_TEST_CLASS_DECLARATION(test_0026_3)
GUI_TEST_CLASS_DECLARATION(test_0027_1)
GUI_TEST_CLASS_DECLARATION(test_0027_2)
GUI_TEST_CLASS_DECLARATION(test_0027_3)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040_1)
GUI_TEST_CLASS_DECLARATION(test_0040_2)
GUI_TEST_CLASS_DECLARATION(test_0040_3)
GUI_TEST_CLASS_DECLARATION(test_0041)

#undef GUI_TEST_SUITE
}//namespace U2

}//namespace

#endif // GTTESTSMCAEDITOR_H

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/mca_editor/GTTestsMcaEditor.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTSMCAEDITOR_H
#define GTTESTSMCAEDITOR_H

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_mca_editor {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_mca_editor"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012_1)
GUI_TEST_CLASS_DECLARATION(test_0012_2)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)
GUI_TEST_CLASS_DECLARATION(test_0013_3)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0015_2)
GUI_TEST_CLASS_DECLARATION(test_0016_1)
GUI_TEST_CLASS_DECLARATION(test_0016_2)
GUI_TEST_CLASS_DECLARATION(test_0017_1)
GUI_TEST_CLASS_DECLARATION(test_0017_2)
GUI_TEST_CLASS_DECLARATION(test_0018_1)
GUI_TEST_CLASS_DECLARATION(test_0018_2)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022_1)
GUI_TEST_CLASS_DECLARATION(test_0022_2)
GUI_TEST_CLASS_DECLARATION(test_0022_3)
GUI_TEST_CLASS_DECLARATION(test_0023_1)
GUI_TEST_CLASS_DECLARATION(test_0023_2)
GUI_TEST_CLASS_DECLARATION(test_0023_3)
GUI_TEST_CLASS_DECLARATION(test_0024_1)
GUI_TEST_CLASS_DECLARATION(test_0024_2)
GUI_TEST_CLASS_DECLARATION(test_0024_3)
GUI_TEST_CLASS_DECLARATION(test_0025_1)
GUI_TEST_CLASS_DECLARATION(test_0025_2)
GUI_TEST_CLASS_DECLARATION(test_0025_3)
GUI_TEST_CLASS_DECLARATION(test_0026_1)
GUI_TEST_CLASS_DECLARATION(test_0026_2)
GUI_TEST_CLASS_DECLARATION(test_0026_3)
GUI_TEST_CLASS_DECLARATION(test_0027_1)
GUI_TEST_CLASS_DECLARATION(test_0027_2)
GUI_TEST_CLASS_DECLARATION(test_0027_3)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040_1)
GUI_TEST_CLASS_DECLARATION(test_0040_2)
GUI_TEST_CLASS_DECLARATION(test_0040_3)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0045_1);
GUI_TEST_CLASS_DECLARATION(test_0045_2);
GUI_TEST_CLASS_DECLARATION(test_0045_3);
GUI_TEST_CLASS_DECLARATION(test_0045_4);

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_mca_editor

}  // namespace U2

#endif  // GTTESTSMCAEDITOR_H
